==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageDirectionalIndexIndicator = /*@__PURE__*/ (() => {
    class AverageDirectionalIndexIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new AverageDirectionalIndexIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return AverageDirectionalIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.zk));
        }
        set zj(a) {
            this.h(AverageDirectionalIndexIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    AverageDirectionalIndexIndicator.$t = /*@__PURE__*/ markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageDirectionalIndexIndicator = /*@__PURE__*/ (() => {
    class AverageDirectionalIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new AverageDirectionalIndexIndicator();
        }
        get_abq() {
            return new AverageDirectionalIndexIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return AverageDirectionalIndexIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.acc));
        }
        set acb(a) {
            this.h(AverageDirectionalIndexIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    AverageDirectionalIndexIndicator.$t = /*@__PURE__*/ markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
})();
